The `starvote_ballots_*.csv` files were downloaded from [https://star.vote](https://star.vote)
on Saturday, May 20, 2023.  The site doesn't make it clear what the files can be used for,
so I assume redistribution is okay.

The `sample_vote_*.csv` files were hand-written by Larry Hastings.
